<img src="https://meerschaum.io/assets/banner_1920x320.png" alt="Meerschaum banner">

| PyPI                                                         | Repository                                                   | License                                                      |
| ------------------------------------------------------------ | ------------------------------------------------------------ | ------------------------------------------------------------ |
| ![PyPI]( https://img.shields.io/pypi/v/meerschaum?color=%2300cc66&label=Version ) | ![GitHub repo size](https://img.shields.io/github/repo-size/bmeares/Meerschaum?label=Repo%20size) | ![PyPI - License](https://img.shields.io/pypi/l/meerschaum?label=License) |
| ![PyPI - Python Version]( https://img.shields.io/pypi/pyversions/meerschaum?label=Python&logo=python&logoColor=%23ffffff ) | ![Lines of code]( https://img.shields.io/tokei/lines/github/bmeares/Meerschaum?label=Total%20Lines ) |                                                              |


# What is Meerschaum?
Meerschaum is a platform for quickly creating and managing time-series data streams called **pipes**. With Meerschaum, you can have a data visualization stack running in minutes.

The power of the Meerschaum system comes from projects like [pandas](https://pandas.pydata.org/), [sqlalchemy](https://www.sqlalchemy.org/), [fastapi](https://fastapi.tiangolo.com/), and more.

# Why Meerschaum?

If you've worked with time-series data, you know the headaches that come with ETL. Meerschaum is a system that makes consolidating and syncing data easy.

Anytime you need to move time-series data from somewhere like a database, API, MQTT topic, or even CSV files (we've all done it at some point), you usually end up writing some scripts that silently break in a year. Meerschaum instead gives you better tools to define and sync your data streams. And don't worry — you can always incorporate Meerschaum into your existing scripts.

# Quick Start

For a more thorough setup guide, visit the [Getting Started](https://meerschaum.io/get-started/) page at [meerschaum.io](https://meerschaum.io).

## TL;DR

```bash
pip install -U --user meerschaum
mrsm stack up -d
mrsm bootstrap pipes
```

## Usage Documentation

Please visit [meerschaum.io](https://meerschaum.io) for setup, usage, and troubleshooting information. You can find technical documentation at [docs.meerschaum.io](https://docs.meerschaum.io).

## Plugins

Meerschaum has a straightforward plugin system. For details on installing, using, and writing plugins, check out the [plugins documentation](https://meerschaum.io/reference/plugins/types-of-plugins) at [meerschaum.io](https://meerschaum.io).

# Support Meerschaum's Development

I'm a full-time graduate student, and I work on Meerschaum in my free time. If you enjoy Meerschaum and want to support its development, you can [buy me a beer (or coffee)](https://www.buymeacoffee.com/bmeares).
